//Parallel Camera test code
// RJA captures jpg image from camera and shows on EVE2 display
//Copyright (C) Raymond Allen 2021
//MIT License

#include "Platform.h"
#include "Antares.h"  //RJA implementing this gd2-lib code using Matrix Orbital's driver

#include "Cam.h"  //Digital Video Port (DVP) camera driver for P2
struct __using("CameraCapture_JPEG.spin2") Camera2;
//QVGA over VGA driver at 16bpp (using as diagnostic)
struct __using("QVGA_16bpp.spin2") QVGA1;  //just using for buffer now  

//Camera DV capture
struct __using("CameraCapture.spin2") Camera1;

char filename[] = "OV2640.jpg";

i2c_Port I2C1;

int nLoop = 0;
uint8_t* pBuff;

void Setup()
{
	//Using VGA as diagnostic
	int basepin = 8; //basepin of A/V accessory with VGA
	QVGA1.start(basepin, basepin + 4);
	pBuff = QVGA1.GetBuffer();

	//Camera1.Start(QVGA1.GetBuffer(), DVP1_Basepin, DVP1_VSYNC, DVP1_HSYNC, DVP1_PixelClock, DVP1_Type);
	Camera2.Start(pBuff, DVP1_Basepin, DVP1_VSYNC, DVP1_HSYNC, DVP1_PixelClock, DVP1_Type);

	i2c_Setup(&I2C1, I2C1_SCLPIN, I2C1_SDAPIN, I2C1_SPEED, I2C1_PULLUP); //setup(i2c_Port*, scl, sda, khz, pullup) 
	printf("I2C Driver started.\n");

	//Create NCO clock for camera
	//InitCamera(DVP1_Xclk, DVP1_PixelClockFreq, DVP1_RST, DVP1_Type, &I2C1, BMP); //RJA added format option 29Dec22
	InitCamera(DVP1_Xclk, DVP1_PixelClockFreq, DVP1_RST, DVP1_Type, &I2C1, JPEG); //RJA added format option 29Dec22

		//get filesystem ready
#if defined(USE_SD)
	//mount("/files", _vfs_open_sdcard());
	mount("/files", _vfs_open_sdcardx(uSD_CLK, uSD_SS, uSD_MOSI, uSD_MISO));//clock pin, select pin, data in, and data out pins, in that order
	chdir("/files");
#elif defined(USE_HOST)
	mount("/files", _vfs_open_host());
	chdir("/files");
#else
	#warning no file system specified, I hope you are compiling for PC
#endif
}

//Scope measurements 31Dec22:
//in QVGA raw mode, pixel clock is 15 MHz
//In QVGA jpeg mode, pixel clock is 10 MHz, capture data on rising edge
//In VGA jpeg mode, pixel clock is 20 MHz, capture data on rising edge
//in SVGA jpeg mode, pixel clock is 15 MHz, captur data on rising edge
//in XGA jpeg mode, pixel clock is 15 MHz, captur data on rising edge
//In 1600x1200 jpeg mode, pixel clock is 20 MHz, capture data on rising edge

void Loop()
{

	printf("Loop #%d\n\n", nLoop++);


	
	//printf("Capturing jpg...\n");
	printf("Image capturing...\n");
	int bytes=Camera2.GetFrame();


	//printf("Scanning for start:\n");
	int istart = 0;
	for (int i = 0; i < 320 * 240 * 2; i++)
	{
		if ((pBuff[i] == 0xFF) && (pBuff[i + 1] == 0xD8))
		{
			printf("Image starts at %d\n", i);
			istart = i;
			break;
		}
	}

	//printf("Scanning for end:\n");
	int iend = -1;
	for (int i = bytes-1000; i < (320 * 240 * 2); i++)
	{
		if ((pBuff[i] == 0xFF) && (pBuff[i + 1] == 0xD9) && (pBuff[i + 2] == 0x00))
		{
			printf("Image ends at %d\n", i + 1);
			iend = i + 1;
			break;
		}
	}



	if ((iend > 0)&&(istart==0))
	{//if data looks good, save to file and show on eve
		// Open the file on SD card by name
		FILE* f = fopen(filename, "wb");
		if (!f)
		{
			printf("%s not open\n", filename);
			fclose(f);
			for (;;) {}
		}

		int size = iend - istart + 1; //bytes + 10;// iend - istart + 1; //

		printf("Image size=%d\n", bytes);


		int w = fwrite(&pBuff[istart], 1, size, f);
		printf("%d bytes written\n", w);
		fclose(f);

		_waitms(10);

		//Display image on EVE
		load(filename);  //automagically configures bitmap handle #0 to show this image
		Clear();
		Begin(BITMAPS);
		Vertex2ii(0, 0);  //RJA: This paints the image.  It knows the image size.
		swap();
	}
	else
		printf("Skipping bad frame.\n");

	if (_rxraw(1)>0)  //stop on any input
		for (;;) 
		{//restart on any inputk
			if (_rxraw(1) > 0)
				break;
		}


}



int main()
{
	begin(); //Start Antares/EVE
    char c=0;
    printf("Starting\n");

    Setup();

    for (;;)
    {
        Loop();
        _waitms(1000);
    }


}





