//P2C Generated Platform.h file
#ifndef _PLATFORM_H_
#define _PLATFORM_H_

enum { _clkfreq = 300_000_000};

// override baud rate for serial, requires use of "_setbaud(_BAUD);" in code
//#ifndef _BAUD
//#define _BAUD 2000000
//#endif

#include "propeller2.h"
#include "stdio.h"
#include "stdlib.h"
#include "stdint.h"
#include "stdbool.h"

#include "i2c.h"  //I2C driver for P2
#include "Cam.h"  //Digital Video Port (DVP) camera driver for P2

enum { heapsize = 16000 };  //override the default heapsize to give more, if needed

//Do we want to use a cog for SPI comms to get faster speed?
//Uncomment line below to use a cog for faster SPI
#define USECOGFORSPI

//Eve's clock is normally 60 MHz, but 72 MHz also works, although audio and video frame rates are off
//Uncomment line below to set Eve's Clock 72 MHz 
//#define Set72MHzEveClock


//Antares uses a P2 smartpin in NCO mode to give clock to EVE3 chip in order to get TV and monitors to accept VGA/720p signals selected by the below
//Note:  Eve sometimes gets stuck when switched from VGA to 720p
//Pick one: (see DisplaySettings.h)
//#define EVE3_720p  
//#define EVE3_1080p
//#define EVE3_VGA  
#define EVE2_70  //7" WVGA LCD
//#define EVE2_43  //4.3" LCD
//#define EVE2_50
//#define EVE2_39
//#define EVE2_38
//#define EVE2_35  //3.5" LCD
//#define EVE2_29


//Audio settings - Can use a cog to convert EVE's digital audio output to a P2 pin in DAC mode for use with, for example, Parallax P2 A/V Accessory board
//Use this define to invoke audio cog
#define ReflectEveAudio  //comment this out to not use a cog for audio output
//Left output with A/V accessory board on basepin #8 is pin 8+6=14
#define ReflectEveAudioPin1  (8 + 6)  
//Right output with A/V accessory board on basepin #8 is pin 8+7=15, set to -1 if not needed
#define ReflectEveAudioPin2  (8 + 7)  //-1


//Backlight Setting
#define BacklightSetting 60 //0==Off, 128==Max. 

//Touchscreen settings 
//Really only need to do something special if have a resistive touch screen, then need to do calibration or load calibration from files
//But, some examples will make fake input if neither type of touchscreen is present
//#define ResistiveTouch
#define CapacitiveTouch  
//Define this if want to use file system to save/restore resistive calibration settings when ResistiveTouch is defined
#define UseFilesForTouchCalibration  //file=ResTouch.dat
//If using a different screen, may want to uncomment the below to force recalibration
//#define ForceTouchCalibration
// Threshold for resistance 
#define RESISTANCE_THRESHOLD                    (1200) //RJA:  for resistive touch panels

#define USE_SD  //Files using P2 Eval's uSD card
//#define USE_HOST  //Files using Plan9 on local host


//Pick one of these board configs or add your own
#define P2Eval //P2 Eval to IDC adapter for Newhaven displays


//P2 Eval board with Ray's Original IDC adapter
#ifdef P2Eval
#define Eve_basepin (16)
#define FT800_CS                                (Eve_basepin+5)
#define FT800_INT                               (Eve_basepin+7) 
#define FT800_PD_N                              (Eve_basepin+6)
#define FT800_SEL_PIN           FT800_CS
//RJA adding more pins
#define FT800_MOSI								(Eve_basepin+0)
#define FT800_MISO								(Eve_basepin+1)
#define FT800_CLK								(Eve_basepin+4)
#define FT800_AUDIO								(Eve_basepin+2)

//The Eval Board's uSD pins
#define uSD_MISO  58 
#define uSD_MOSI  59 
#define uSD_SS  60 
#define uSD_CLK  61

//USB pin definitions Parallax USB adapter board for P2 Eval Board, used by Antares if UseUsbMouse is defined above
#define SERIAL_HOST_BASEPIN 32//24
#define USB_BASE_PIN (SERIAL_HOST_BASEPIN) 
#define USB_ENABLE_PIN (SERIAL_HOST_BASEPIN+1)  //+5 for lower port, +1 for upper port
#define USB_DM_PIN (SERIAL_HOST_BASEPIN+2)  //USB is on +6 (and +7) for lower port, +2 (and +3) for upper port
#define USB_ERR_LED_PIN 57       //Using P2 Eval board's P57 led for error display
#endif //P2Eval



#define DVP1_Type OV2640 //OV5640//OV2640 //OV5640
//For Eval Adapters
#define DVP1_Basepin (32)
#define DVP1_Xclk (DVP1_Basepin+8+7)
#define DVP1_PixelClock  (DVP1_Basepin + 8 + 6) //video clock MISO pin
#define DVP1_PixelClockFreq (20000000)//(20000000)
#define DVP1_RST  (DVP1_Basepin + 8 + 5) //digital video reset pin
#define DVP1_SDA  (DVP1_Basepin + 8 + 0)   //digital video SDA pin
#define DVP1_SCL  (DVP1_Basepin + 8 + 1)   //digital video SCL pin
#define DVP1_VSYNC  (DVP1_Basepin + 8 + 4)  //VSYNC pin
#define DVP1_HSYNC  (DVP1_Basepin + 8 + 3)  //HREF pin
#define DVP1_PWDN = (DVP1_Basepin + 8 + 2)  //Power Down
//I2C Bus Pins and Settings for I2CScan1
#define I2C1_SCLPIN (DVP1_Basepin + 8 + 1) //I2C1_SCLPIN (56)
#define I2C1_SDAPIN (DVP1_Basepin + 8 + 0) //I2C1_SDAPIN (57)
#define I2C1_SPEED 400
#define I2C1_PULLUP PU_3K3

////For Robot board
//#define DVP1_Basepin (24)
//#define DVP1_Xclk (DVP1_Basepin+8+5)
//#define DVP1_PixelClock  (DVP1_Basepin + 8 + 4) //video clock MISO pin
//#define DVP1_PixelClockFreq (20000000)
//#define DVP1_RST  (DVP1_Basepin + 8 + 3) //digital video reset pin
//#define DVP1_SDA  (57)   //digital video SDA pin
//#define DVP1_SCL  (56)   //digital video SCL pin
//#define DVP1_VSYNC  (DVP1_Basepin + 8 + 2)  //VSYNC pin
//#define DVP1_HSYNC  (DVP1_Basepin + 8 + 0)  //HREF pin
//#define DVP1_PWDN = (DVP1_Basepin + 8 + 1)  //Power Down
////I2C Bus Pins and Settings for I2CScan1
//#define I2C1_SCLPIN (56) //I2C1_SCLPIN (56)
//#define I2C1_SDAPIN (57) //I2C1_SDAPIN (57)
//#define I2C1_SPEED 400
//#define I2C1_PULLUP PU_3K3

#include "DisplaySettings.h" //Settings for various types of displays are here, 


//some types not yet defined in FlexSpin, or needed to translate Arduino code
typedef char  byte;
typedef unsigned char uchar;
typedef char		bool_t;
typedef char		char8_t;
typedef unsigned char	uchar8_t;
typedef unsigned char prog_uchar8_t;
typedef signed char	schar8_t;
typedef float		float_t;

//RJA:  Seem to need this...
#define min(x,y)  ((x) > (y) ? (y) : (x))
#define max(x,y)  ((x) > (y) ? (x) : (y))





#endif /*_PLATFORM_H_*/
/* Nothing beyond this*/

